<?PHP // $Id$ 
      // moodle.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004110200)


$string['action'] = 'Accin';
$string['activities'] = 'Actividades';
$string['activity'] = 'Actividad';
$string['activityclipboard'] = 'Moviendo esta actividad: <b>$a</b>';
$string['activityiscurrentlyhidden'] = 'Lo siento, esta actividad actualmente est oculta';
$string['activitymodule'] = 'Actividad del mdulo';
$string['activityreport'] = 'Informe de Actividades';
$string['activityselect'] = 'Selecciona esta actividad para moverla a otro sitio';
$string['activitysince'] = 'Actividad desde $a';
$string['add'] = 'Aadir';
$string['addadmin'] = 'Aadir administrador';
$string['addcreator'] = 'Aadir autor de curso';
$string['added'] = 'Aadido $a';
$string['addedtogroup'] = 'Aadido al grupo $a';
$string['addedtogroupnot'] = 'No aadido al grupo $a';
$string['addedtogroupnotenrolled'] = 'No aadido al grupo $a porque no est inscrito en el curso';
$string['addinganew'] = 'Aadiendo un nuevo $a';
$string['addinganewto'] = 'Aadiendo un nuevo $a->what a $a->to';
$string['addingdatatoexisting'] = 'Aadiendo datos a los existentes';
$string['addnewcategory'] = 'Aadir nueva categora';
$string['addnewcourse'] = 'Aadir un nuevo curso';
$string['addnewuser'] = 'Nuevos usuarios';
$string['address'] = 'Direccin';
$string['addstudent'] = 'Aadir alumno';
$string['addteacher'] = 'Aadir profesor';
$string['admin'] = 'Admin';
$string['adminhelpaddnewuser'] = 'Para crear manualmente una nueva cuenta de usuario';
$string['adminhelpassignadmins'] = 'Los administradores pueden hacer todo e ir a todas partes en este sitio';
$string['adminhelpassigncreators'] = 'Los autores pueden crear nuevos cursos y ensear en ellos';
$string['adminhelpassignstudents'] = 'Entre en un curso y aada alumnos desde el men de administracin';
$string['adminhelpassignteachers'] = 'Seleccione un curso y use el icono para aadir profesores';
$string['adminhelpauthentication'] = 'Puede usar cuentas de usuario internas o bases de datos externas';
$string['adminhelpbackup'] = 'Configurar copias de seguridad automticas y su programacin';
$string['adminhelpconfiguration'] = 'Configure el aspecto y la manera en que el sitio funciona';
$string['adminhelpconfigvariables'] = 'Configure las variables que afectan a la operativa general del sitio';
$string['adminhelpcourses'] = 'Defina cursos y categoras y asgneles personal';
$string['adminhelpedituser'] = 'Vea la lista de usuarios y edite cualquiera de ellos';
$string['adminhelplanguage'] = 'Para comprobar y editar el idioma en uso';
$string['adminhelplogs'] = 'Vea los registro de toda la actividad del sitio';
$string['adminhelpmanagedatabase'] = 'Acceso a la base de datos directamente (tenga cuidado!)';
$string['adminhelpmanagefilters'] = 'Configurar los filtros de texto y su configuracin';
$string['adminhelpmanagemodules'] = 'Gestione los mdulos instalados y su configuracin';
$string['adminhelpsitefiles'] = 'Para publicar archivos o cargar copias de seguridad externas';
$string['adminhelpsitesettings'] = 'Defina el aspecto de la pgina de entrada';
$string['adminhelpthemes'] = 'Elija el aspecto del sitio';
$string['adminhelpuploadusers'] = 'Importar nuevos usuarios desde un archivo de texto';
$string['adminhelpusers'] = 'Definir los usuarios y establecer el sistema de autenticacin';
$string['administration'] = 'Administracin';
$string['administrator'] = 'Administrador';
$string['administrators'] = 'Administradores';
$string['advancedfilter'] = 'Filtro avanzado';
$string['again'] = 'de nuevo';
$string['all'] = 'Todos';
$string['alldays'] = 'Todos los das';
$string['allfieldsrequired'] = 'Todos los campos son obligatorios';
$string['allgroups'] = 'Todos los grupos';
$string['alllogs'] = 'Todas las entradas';
$string['allow'] = 'Permitir';
$string['allowguests'] = 'Este curso permite entrar como invitado';
$string['allownot'] = 'No permitir';
$string['allparticipants'] = 'Todos los participantes';
$string['alphanumerical'] = 'Slo puede contener caracteres alfanumricos';
$string['alreadyconfirmed'] = 'La inscripcin ha sido confirmada';
$string['answer'] = 'Respuesta';
$string['areyousuretorestorethis'] = 'Est seguro de querer restaurarlo?';
$string['areyousuretorestorethisinfo'] = 'Posteriormente tendr la posibilidad de aadir esta copia a un curso existente o crear uno completamente nuevo.';
$string['assessment'] = 'Evaluacin';
$string['assignadmins'] = 'Asignacin de administradores';
$string['assigncreators'] = 'Asignacin de autores de cursos';
$string['assignstudents'] = 'Asignacin de estudiantes';
$string['assignstudentsnote'] = 'Nota: puede no ser necesario usar esta pgina, ya que los alumnos se pueden inscribir ellos mismos en este curso.';
$string['assignstudentspass'] = 'Todo lo que puede necesitar hacer es notificar a sus alumnos la clave de acceso a este curso, que es la siguiente: \'$a\'';
$string['assignteachers'] = 'Asignacin de profesores';
$string['authentication'] = 'Autenticacin';
$string['autosubscribe'] = 'Foro de auto-suscripcin';
$string['autosubscribeno'] = 'No: no me suscriba automticamente a los foros';
$string['autosubscribeyes'] = 'S: cuando ponga un mensaje, suscribirme a ese foro';
$string['availability'] = 'Disponibilidad';
$string['availablecourses'] = 'Cursos disponibles';
$string['backup'] = 'Copia de seguridad';
$string['backupcoursefileshelp'] = 'Si se habilita, los archivos del curso se incluirn en la copia de seguridad automtica';
$string['backupdate'] = 'Fecha de la copia de seguridad';
$string['backupdetails'] = 'Detalles de la copia de seguridad';
$string['backupfilename'] = 'copia de seguridad';
$string['backupfinished'] = 'Copia de seguridad completada con xito';
$string['backupincludemoduleshelp'] = 'Escoja si desea incluir los mdulos del curso, con o sin los datos de usuario, en la copia de seguridad';
$string['backupkeephelp'] = 'Cuntas copias de seguridad recientes de cada curso desea conservar? (las ms antiguas sern borradas automticamente)';
$string['backuplogshelp'] = 'Si se habilita, los registros de actividad del curso se incluirn en el copia de seguridad automtica';
$string['backupnameformat'] = '%%d%%m%%Y-%%H%%M';
$string['backuporiginalname'] = 'Nombre de la copia de seguridad';
$string['backupuserfileshelp'] = 'Para seleccionar si desea incluir los archivos de usuario (p.e. imgenes) en la copia de seguridad automtica';
$string['backupusershelp'] = 'Seleccione si desea incluir todos los usuarios del servidor o solo los vinculados a cada curso';
$string['backupversion'] = 'Versin de la copia de seguridad';
$string['bycourseorder'] = 'Por orden del curso';
$string['cancel'] = 'Cancelar';
$string['categories'] = 'Categoras de cursos';
$string['category'] = 'Categora';
$string['categoryadded'] = 'La categora \'$a\' ha sido aadida';
$string['categorydeleted'] = 'La categora \'$a\' ha sido eliminada';
$string['categoryduplicate'] = 'Ya existe una categora llamada \'$a\' ';
$string['changedpassword'] = 'Contrasea cambiada';
$string['changepassword'] = 'Cambiar contrasea';
$string['changessaved'] = 'Cambios guardados';
$string['checkingbackup'] = 'Comprobando copia de seguridad';
$string['checkingcourse'] = 'Comprobando curso';
$string['checkinginstances'] = 'Comprobando instancias';
$string['checkingsections'] = 'Comprobando secciones';
$string['checklanguage'] = 'Comprobar idioma';
$string['choose'] = 'Escoger';
$string['choosecourse'] = 'Escoja un curso';
$string['chooselivelogs'] = 'O vea la actividad actual';
$string['chooselogs'] = 'Escoja las entradas que desea ver';
$string['choosereportfilter'] = 'Elija un filtro para el informe';
$string['choosetheme'] = 'Colores y fuentes';
$string['chooseuser'] = 'Elija un usuario';
$string['city'] = 'Ciudad';
$string['cleaningtempdata'] = 'Eliminando datos temporales';
$string['closewindow'] = 'Cerrar esta ventana';
$string['comparelanguage'] = 'Compare y edite el idioma actual';
$string['complete'] = 'Completo';
$string['configallowunenroll'] = 'Si escoge \"S\", los alumnos podrn darse de baja de sus cursos cuando quieran. De otro modo, ellos no tendrn esa posibilidad y este proceso ser controlado exclusivamente por los profesores y administradores.';
$string['configcachetext'] = 'Para sitios grandes o que usan filtros de texto, esta configuracin puede acelerar las cosas. Las copias de los textos permanecern en su formulario por el tiempo aqu especificado. Si el lapso es muy pequeo puede ralentizar el proceso ligeramente, pero si es muy grande puede significar que tardar mucho tiempo para actualizar los textos (con nuevos enlaces, por ejemplo).';
$string['configcountry'] = 'Si indica un pas aqu, ser el pas por defecto para las cuentas de los nuevos usuarios. Para obligar a los usuarios a elegir su pas, djelo en blanco.';
$string['configdebug'] = 'Si activa esta opcin, la informacin de errores de PHP se incrementar. Esto slo es til para desarrolladores.';
$string['configerrorlevel'] = 'Elija la cantidad de advertencias php que desea ver. Normal suele ser la mejor opcin.';
$string['configforcelogin'] = 'Normalmente la pgina de inicio del sitio y el listado de cursos (no los cursos) es visible para todos, aunque no hayan entrado en l. Si desea forzar el acceso de los usuarios antes de ver a primera pgina, habilite esta opcin.';
$string['configframename'] = 'Si est incrustando Moodle en un marco Web, ponga el nombre del marco aqu. En caso contrario este valor debe permanecer como \'_top\'';
$string['configgdversion'] = 'Este parmetro indica la versin instalada de GD. La versin mostrada es la que detect el programa. No la cambie sin saber exactamente lo que est haciendo.';
$string['confightmleditor'] = 'Elija si permitir o no el uso del editor HTML incrustado. Aunque escoja permitir, este editor slo aparecer cuando el usuario use un navegador compatible (IE 5.5 o posterior). Los usuarios tambin pueden elegir no utilizarlo.';
$string['configidnumber'] = 'Esta opcin especifica si: a) No se solicita ningn nmero de identificacin a los usuarios. b) Se solicita el nmero pero se permite que el espacio quede en blanco. c) Se solicita el nmero y es indispensable que lo pongan. Si se da el nmero de identificacin, ste es mostrado en su perfil de usuario.';
$string['configintro'] = 'En esta pgina puede especificar un nmero de variables de configuracin que ayudan a que Moodle funcione correctamente en el servidor. No se preocupe demasiado, los valores por defecto normalmente funcionan muy bien y siempre puede volver a esta pgina y cambiar estos valores.';
$string['configintroadmin'] = 'En esta pgina debe configurar la cuenta para el administrador principal, que le dar control total sobre el sitio. Asegrese de darle un nombre de usuario y contrasea seguras adems de una direccin de correo electrnico vlida. Posteriormente podr crear ms cuentas de administracin.';
$string['configintrosite'] = 'Esta pgina le permite configurar la pgina principal y el nombre del nuevo sitio. Ms tarde podr volver aqu para cambiar estas opciones en cualquier momento, usando el enlace \'Configuracin del Sitio\' que hay en la pgina principal.';
$string['configlang'] = 'Elija un idioma para el sitio. Los usuarios pueden personalizar esta opcin posteriormente.';
$string['configlangdir'] = 'La mayora de los idiomas se escriben de izquierda a derecha, pero algunos, como el rabe o el hebreo, se escriben de derecha a izquierda.';
$string['configlanglist'] = 'Deje este espacio en blanco para permitir a los usuarios elegir cualquier idioma que usted tenga en la instalacin de Moodle. Sin embargo, puede reducir el men de idiomas introduciendo una lista separada por comas de los cdigos de idioma que quiera. Por ejemplo: en,es_es,fr,it';
$string['configlangmenu'] = 'Elija si desea o no presentar el men de eleccin de idioma en la pgina principal, pgina de entrada, etc. Esto no afectar a la posibilidad del usuario de establecer su idioma preferido en su propio perfil de usuario.';
$string['configlocale'] = 'Elija la configuracin local -esto afectar al formato e idioma de las fechas-. Necesita tener esta configuracin instalada en su sistema operativo (ej. en_US o es_ES). Si no sabe que poner, djelo en blanco.';
$string['configloglifetime'] = 'Este parmetro especifica la cantidad de tiempo durante la que usted quiere guardar la informacin sobre la actividad del usuario. Los registros que llevan guardados ms tiempo del que aqu se indica se borrarn automticamente. Lo mejor es guardar los registros tanto tiempo como sea posible, para el caso de que pueda necesitarlos, pero si tiene un servidor con mucho trfico y est sufriendo problemas de rendimiento, preferir rebajar el tiempo de vida de los registros.';
$string['configlongtimenosee'] = 'Si los estudiantes no han participado durante este tiempo, sern automticamente borrados de los cursos. Este parmetro especifica ese lmite de tiempo.';
$string['configmaxeditingtime'] = 'Especifique el tiempo que los participantes tienen para editar sus mensajes. Normalmente 30 minutos es un valor adecuado.';
$string['configproxyhost'] = 'Si este <B>servidor</B> necesita un proxy (por ejemplo un firewall) para acceder a Internet, indique el nombre del proxy y el puerto.';
$string['configsecureforms'] = 'Moodle puede usar un nivel adicional de seguridad al aceptar datos desde formularios Web. Si esto est habilitado, la variable del navegador HTTP_REFERER se contrasta con la direccin actual en el formulario. En algunos pocos casos esto puede causar problemas si el usuario est usando un cortafuegos (ej. Zonealarm) configurado para quitar los HTTP_REFERER de su trfico web. Sntomas de esto son quedarse \"atascado\" en un formulario. Si sus usuarios estn teniendo problemas con la pgina de inscripcin (por ejemplo) debe deshabilitar esta opcin, aunque hacerlo dejar su sitio ms abierto a la posibilidad de ataques mediante \"fuerza bruta\". Si tiene dudas, deje esto establecido como \'Si\'.';
$string['configsessiontimeout'] = 'Si una persona ha entrado en este sitio y permanece inactiva durante un largo perodo de tiempo (sin cargar pginas) automticamente es puesta fuera del sistema (finaliza su sesin). Esta variable especifica cuanto debe durar ese perodo de tiempo.';
$string['configslasharguments'] = 'Los archivos (imgenes, uploads etc.) son proporcionados a travs de un script que usa \'slash arguments\' (la segunda opcin aqu). Este mtodo carga los archivos ms fcilmente en los navegadores, servidores proy, etc. Desafortunadamente, algunos servidores php no permiten este mtodo, por lo que si tiene problemas para subir archivos (como las fotos de los usuarios, p.e.), cambie esta variable a la primera opcin.';
$string['configsmtphosts'] = 'Escriba el nombre completo de uno o ms servidores SMTP que Moodle debera usar para enviar correo (p.e. \'mail.a.com\' o \'mail.a.com;mail.b.com\'). Si lo deja en blanco, Moodle utilizar el mtodo estndar de PHP para enviar el correo electrnico.';
$string['configsmtpuser'] = 'Si ha especificado un servidor SMTP anteriormente, y ste requiere autenticacin, introduzca el nombre de usuario y contrasea aqu.';
$string['configteacherassignteachers'] = 'Se permite a los profesores aadir otros profesores en los cursos en que ellos ensean? Si se escoge \"No\", nicamente los autores y administradores pueden asignar profesores.';
$string['configunzip'] = 'Indique la ubicacin del programa UNZIP (slo UNIX). Se necesita para descomprimir los archivos en el servidor.';
$string['configuration'] = 'Configuracin';
$string['configvariables'] = 'Variables';
$string['configwarning'] = 'Tenga cuidado al cambiar estos valores, pues si no son correctos puede ocasionarle problemas.';
$string['configzip'] = 'Indique la ubicacin del programa ZIP (slo UNIX). Se necesita para descomprimir los archivos en el servidor.';
$string['confirmed'] = 'Inscripcin confirmada';
$string['confirmednot'] = 'Su inscripcin no ha sido an confirmada';
$string['continue'] = 'Continuar';
$string['cookiesenabled'] = 'Las Cookies deben estar habilitadas en su navegador';
$string['copy'] = 'copia';
$string['copyingcoursefiles'] = 'Copiando los archivos del curso';
$string['copyinguserfiles'] = 'Copiando los archivos de usuario';
$string['copyingzipfile'] = 'Copiando el archivo zip';
$string['copyrightnotice'] = 'Copyright';
$string['country'] = 'Pas';
$string['course'] = 'Curso';
$string['courseavailable'] = 'Este curso est disponible para los alumnos';
$string['courseavailablenot'] = 'Este curso no est disponible para los alumnos';
$string['coursebackup'] = 'Copia de seguridad del curso';
$string['coursecategories'] = 'Categoras de cursos';
$string['coursecategory'] = 'Categora de cursos';
$string['coursecreators'] = 'Autores de curso';
$string['coursefiles'] = 'Archivos del curso';
$string['courseformats'] = 'Formatos de curso';
$string['coursegrades'] = 'Calificaciones del curso';
$string['courseinfo'] = 'Informacin del curso';
$string['courserestore'] = 'Restaurar curso';
$string['courses'] = 'Cursos';
$string['courseupdates'] = 'Actualizaciones de cursos';
$string['create'] = 'Crear';
$string['createaccount'] = 'Crear cuenta';
$string['createfolder'] = 'Crear una carpeta en $a';
$string['createuserandpass'] = 'Crear un nuevo usuario y contrasea para acceder al sistema';
$string['createziparchive'] = 'Crear archivo zip';
$string['creatingcategoriesandquestions'] = 'Creando categoras y preguntas';
$string['creatingcoursemodules'] = 'Creando mdulos del curso';
$string['creatinglogentries'] = 'Creando entradas de registro';
$string['creatingnewcourse'] = 'Creando un nuevo curso';
$string['creatingscales'] = 'Creando niveles';
$string['creatingsections'] = 'Creando secciones';
$string['creatingtemporarystructures'] = 'Creando estructuras temporales';
$string['creatingusers'] = 'Creando usuarios';
$string['creatingxmlfile'] = 'Creando archivo XML';
$string['currentcourseadding'] = 'Curso actual, aadindole datos';
$string['currentcoursedeleting'] = 'Curso actual, procediendo a su borrado';
$string['currentlanguage'] = 'Idioma actual';
$string['currentlocaltime'] = 'su hora local actual';
$string['currentrelease'] = 'Informacin sobre la versin actual';
$string['currentversion'] = 'Versin actual';
$string['databasechecking'] = 'Actualizando la base de datos: version $a->oldversion a $a->newversion...';
$string['databasesetup'] = 'Configurando la base de datos';
$string['databasesuccess'] = 'La base de datos se ha actualizado satisfactoriamente';
$string['databaseupgradebackups'] = 'La versin de la copia de seguridad es ahora $a';
$string['databaseupgrades'] = 'Actualizando la base de datos';
$string['datemostrecentfirst'] = 'Fecha - la ms reciente al principio';
$string['datemostrecentlast'] = 'Fecha - la ms reciente al final';
$string['day'] = 'da';
$string['days'] = 'das';
$string['defaultcoursefullname'] = 'Nombre del curso';
$string['defaultcourseshortname'] = 'ID del curso';
$string['defaultcoursestudent'] = 'Estudiante';
$string['defaultcoursestudents'] = 'Estudiantes';
$string['defaultcoursesummary'] = 'Escriba aqu una concisa e interesante descripcin del curso';
$string['defaultcourseteacher'] = 'Profesor';
$string['defaultcourseteachers'] = 'Profesores';
$string['delete'] = 'Borrar';
$string['deletecheck'] = 'Borrar $a ?';
$string['deletecheckfiles'] = 'Est absolutamente seguro de querer borrar esos archivos?';
$string['deletecheckfull'] = 'Est seguro de que desea borrar definitivamente $a?';
$string['deletecheckwarning'] = 'Est a punto de borrar estos archivos';
$string['deletecompletely'] = 'Borrado por completo';
$string['deletecourse'] = 'Borrar curso';
$string['deletecoursecheck'] = 'Est seguro de que desea borrar definitivamente este curso y toda la informacin que contiene?';
$string['deleted'] = 'Borrado';
$string['deletedactivity'] = 'Se borr $a';
$string['deletedcourse'] = '$a se ha borrado por completo';
$string['deletednot'] = 'No se puede borrar $a!';
$string['deleteselected'] = 'Borrar lo seleccionado';
$string['deletingcourse'] = 'Borrando $a';
$string['deletingexistingcoursedata'] = 'Borrando datos existentes del curso';
$string['deletingolddata'] = 'Borrando datos antiguos';
$string['department'] = 'Departamento';
$string['description'] = 'Descripcin';
$string['disable'] = 'Inhabilitado';
$string['displayingfirst'] = 'Se muestra slo la primera $a->count $a->things ';
$string['displayingrecords'] = 'Mostrando $a registros';
$string['displayingusers'] = 'Mostrando usuarios del $a->start al $a->end';
$string['documentation'] = 'Documentacin de Moodle ';
$string['donotask'] = 'No preguntar';
$string['down'] = 'Abajo';
$string['downloadexcel'] = 'Descargar en formato .xls';
$string['downloadtext'] = 'Descargar en formato de texto';
$string['doyouagree'] = 'Ha ledo y comprendido estas condiciones?';
$string['edit'] = 'Editar $a';
$string['editcoursesettings'] = 'Editar la configuracin del curso';
$string['editinga'] = 'Editando $a';
$string['editmyprofile'] = 'Editar informacin';
$string['editsummary'] = 'Editar informe';
$string['editthisactivity'] = 'Editar esta actividad';
$string['editthiscategory'] = 'Editar esta categora';
$string['edituser'] = 'Edicin de usuarios';
$string['email'] = 'Correo electrnico';
$string['emailconfirm'] = 'Confirme su cuenta';
$string['emailconfirmation'] = 'Hola $a->firstname,

Se ha solicitado la apertura de una nueva cuenta en \'$a->sitename\' utilizando su direccin de correo electrnico.

Para confirmar su nueva cuenta, por favor vaya a la siguiente direccin web:

  $a->link

En la mayora de los programas de email, debera aparecer como un enlace de color azul en el que puede pinchar. Si eso no funciona, copie y pegue la direccin en la barra de direccines de su navegador

Gracias

$a->admin';
$string['emailconfirmationsubject'] = '$a: confirmacin de cuenta';
$string['emailconfirmsent'] = '   <P>Hemos enviado un correo electrnico a <B>$a</B>,

   <P>donde encontrar unas sencillas instrucciones para terminar el proceso.

   <P>Si encuentra alguna dificultad, por favor contacte con el Administrador del Sistema.';
$string['emaildisable'] = 'Esta direccin de correo est inhabilitada';
$string['emaildisplay'] = 'Mostrar correo';
$string['emaildisplaycourse'] = 'Mostrar mi direccin de correo slo a mis compaeros de curso';
$string['emaildisplayno'] = 'Ocultar a todos mi direccin de correo';
$string['emaildisplayyes'] = 'Mostrar a todos mi direccin de correo';
$string['emailenable'] = 'Esta direccin de correo est habilitada';
$string['emailexists'] = 'Esta direccin de correo ya est registrada.';
$string['emailformat'] = 'Formato de correo';
$string['emailmustbereal'] = 'IMPORTANTE: Para poder finalizar correctamente el proceso, debe incluir una direccin de correo electrnico real';
$string['emailpasswordconfirmation'] = 'Hola $a->firstname,

Alguien (probablemente usted) ha solicitado una nueva contrasea para su cuenta en \'$a->sitename\'.

Para confirmar esta solicitud y obtener una nueva contrasea que le ser enviada por medio de correo electrnico, vaya a la siguiente direccin web:

  $a->link

En la mayora de los programas de email, debera aparecer como un enlace de color azul en el que puede pinchar. Si eso no funciona, copie y pegue la direccin en la barra de direccin de su navegador.

Si necesita ayuda, contacte por favor con el administrador del sitio,
$a->admin';
$string['emailpasswordconfirmationsubject'] = '$a: confirmacin de cambio de contrasea';
$string['emailpasswordconfirmsent'] = 'Se debera haber enviado un mensaje a su direccin: <strong>$a</strong>.
<p>El mensaje contiene instrucciones sencillas para confirmar y completar este cambio de contrasea.
Si sigue teniendo problemas, contacte con el administrador del sitio.';
$string['emailpasswordsent'] = 'Gracias por confirmar el cambio de contrasea.
<p>Se ha enviado un mensaje que contiene su nueva contrasea a su direccin: <strong>$a->email</strong>.
<p>La nueva contrasea ha sido generada automticamente - usted puede
<a href=$a->link>cambiar esta contrasea</a> por alguna otra ms fcil de recordar.';
$string['enable'] = 'Permitir';
$string['enrolmentconfirmation'] = 'Est a punto de inscribirse como alumno en este curso. <br />Est seguro de que desea hacerlo?';
$string['enrolmentkey'] = 'Clave de acceso';
$string['enrolmentkeyfrom'] = 'Este curso requiere el uso de una \'clave de acceso\'. Si ha sido admitido<br />

en l y no le hemos enviado la clave, por favor hganoslo saber.';
$string['enrolmentkeyhint'] = 'Esta \'clave de acceso\' es incorrecta, por favor intntelo de nuevo<br />

(Una pista: comienza con \'$a\')';
$string['entercourse'] = 'Clic aqu para entrar al curso';
$string['enteremailaddress'] = 'Escriba su direccin de correo. Una nueva contrasea le ser enviada.';
$string['error'] = 'Error';
$string['errortoomanylogins'] = 'Lo sentimos, ha agotado el nmero permitido de intentos. Reinicie su navegador.';
$string['existing'] = 'Existente';
$string['existingadmins'] = 'Administradores existentes';
$string['existingcourse'] = 'Curso existente';
$string['existingcourseadding'] = 'Curso existente, aadindole datos';
$string['existingcoursedeleting'] = 'Curso existente, borrndolo primero';
$string['existingcreators'] = 'Autores de curso existentes';
$string['existingstudents'] = 'Alumnos inscritos';
$string['existingteachers'] = 'Profesores existentes';
$string['feedback'] = 'Respuesta';
$string['filemissing'] = 'No se encuentra $a';
$string['files'] = 'Archivos';
$string['filesfolders'] = 'Archivos/directorios';
$string['filloutallfields'] = 'Por favor rellene todos los campos de este formulario';
$string['findmorecourses'] = 'Encontrar ms cursos...';
$string['firstname'] = 'Nombre';
$string['firsttime'] = 'Registrarse como alumno';
$string['followingoptional'] = 'Los siguientes datos son opcionales';
$string['followingrequired'] = 'Los siguientes datos son indispensables';
$string['forgotten'] = 'Olvid su nombre de usuario o contrasea?';
$string['format'] = 'Formato';
$string['formathtml'] = 'Formato HTML';
$string['formatplain'] = 'Formato de texto plano';
$string['formatsocial'] = 'Formato Social';
$string['formattext'] = 'Formato automtico';
$string['formattexttype'] = 'Tipo de formato';
$string['formattopics'] = 'Formato Temas';
$string['formatweeks'] = 'Formato Semanal';
$string['formatwiki'] = 'Formato Wiki';
$string['from'] = 'Desde';
$string['frontpagecategorynames'] = 'Mostrar un listado de categoras';
$string['frontpagecourselist'] = 'Mostrar un listado de cursos';
$string['frontpagedescription'] = 'Encabezado de la pgina';
$string['frontpageformat'] = 'Formato de encabezado';
$string['frontpagenews'] = 'Mostrar items de noticias';
$string['fulllistofcourses'] = 'Todos los cursos';
$string['fullname'] = 'Nombre completo';
$string['fullprofile'] = 'Informacin completa';
$string['fullsitename'] = 'Nombre completo del sitio';
$string['gd1'] = 'GD 1.x est instalado';
$string['gd2'] = 'GD 2.x est instalado';
$string['gdneed'] = 'GD debe estar instalado para ver este grfico';
$string['gdnot'] = 'GD no est instalado';
$string['gpl'] = 'Copyright (C) 2001-2002  Martin Dougiamas  (http://dougiamas.com)<br /> Traduccin: Antonio J. Navarro Vergara (http://www.sextaisla.com)
Este programa es software gratuito. Ud. puede redistribuirlo y/o modificarlo bajo los trminos de GNU General Public License segn la publicacin de The Free Software Foundation; incluso la versin 2 o alguna posterior.

<br />

Para ms detalles vea: http://www.gnu.org/copyleft/gpl.html';
$string['grade'] = 'Calificacin';
$string['grades'] = 'Calificaciones';
$string['groupadd'] = 'Aadir nuevo grupo';
$string['groupaddusers'] = 'Aadir lo seleccionado al grupo';
$string['guestskey'] = 'Permitir entrar a estudiantes con clave';
$string['guestsno'] = 'No admitir invitados';
$string['guestsnotallowed'] = 'Lo sentimos, \'$a\' no permite el acceso a invitados.';
$string['guestsyes'] = 'Permitir entrar a estudiantes sin clave';
$string['guestuser'] = 'Invitado';
$string['guestuserinfo'] = 'Este usuario slo puede leer en ciertos cursos.';
$string['help'] = 'Ayuda';
$string['helpemoticons'] = 'Usar emoticonos';
$string['helpformatting'] = 'Acerca de formatear texto';
$string['helphtml'] = 'Cmo escribir html';
$string['helpindex'] = 'Indice de todos los archivos de ayuda';
$string['helppicture'] = 'Cmo subir una imagen';
$string['helpquestions'] = 'Cmo responder preguntas';
$string['helpreading'] = 'Lea con atencin';
$string['helprichtext'] = 'Sobre el editor HTML';
$string['helpsummaries'] = 'Acerca de estos resmenes';
$string['helptext'] = 'Cmo escribir texto';
$string['helpwiki'] = 'Cmo escribir texto Wiki';
$string['helpwriting'] = 'Escriba cuidadosamente';
$string['hide'] = 'Ocultar';
$string['hits'] = 'Visitas';
$string['hitsoncourse'] = 'Visitas a $a->coursename de $a->username';
$string['hitsoncoursetoday'] = 'Visitas de hoy a $a->coursename de $a->username';
$string['home'] = 'Pgina Principal';
$string['hour'] = 'hora';
$string['hours'] = 'horas';
$string['howtomakethemes'] = 'Cmo desarrollar nuevos temas';
$string['htmleditor'] = 'Usar editor de HTML';
$string['htmleditoravailable'] = 'El editor HTML est disponible';
$string['htmleditordisabled'] = 'Usted ha desactivado el editor HTML en su perfil de usuario personal.';
$string['htmleditordisabledadmin'] = 'El administrador ha deshabilitado el editor HTML';
$string['htmleditordisabledbrowser'] = 'Para utilizar el editor HTML se requiere Internet Explorer 5.5 o superior.';
$string['htmlformat'] = 'Formato HTML';
$string['icqnumber'] = 'Nmero de ICQ';
$string['idnumber'] = 'Nmero de id.';
$string['inactive'] = 'Inactivo';
$string['include'] = 'Incluir';
$string['includeallusers'] = 'Incluir todos los usuarios';
$string['includecoursefiles'] = 'Incluir archivos del curso';
$string['includecourseusers'] = 'Incluir usuarios del curso';
$string['included'] = 'Incluido';
$string['includelogentries'] = 'Incluir registro de entradas';
$string['includeneededusers'] = 'Incluir usuarios necesarios';
$string['includeuserfiles'] = 'Incluir archivos de usuario';
$string['invalidemail'] = 'Direccin de correo no vlida';
$string['invalidlogin'] = 'No es correcto, por favor intntelo de nuevo';
$string['jumpto'] = 'Saltar a...';
$string['langltr'] = 'Direccin normal del lenguaje (izquierda a derecha)';
$string['langrtl'] = 'Direccin inversa del lenguaje (derecha a izquierda)';
$string['language'] = 'Idioma';
$string['languagegood'] = 'Este idioma est actualizado! :-)';
$string['lastaccess'] = 'ltima entrada';
$string['lastedited'] = 'ltima edicin';
$string['lastmodified'] = 'ltima modificacin';
$string['lastname'] = 'Apellidos';
$string['latestlanguagepack'] = 'Comprobar si hay una versin nueva del paquete de idioma en moodle.org';
$string['latestnews'] = 'Novedades';
$string['leavetokeep'] = 'Dejar en blanco para mantener la contrasea actual';
$string['license'] = 'Licencia GPL';
$string['list'] = 'Lista';
$string['listfiles'] = 'Lista de archivos en $a';
$string['listofallpeople'] = 'Lista total de personas';
$string['livelogs'] = 'Registros en vivo de la ltima hora';
$string['locale'] = 'es_ES';
$string['location'] = 'Ubicacin';
$string['loggedinas'] = 'Ud. est en el sistema como $a.';
$string['loggedinnot'] = 'Ud. no est en el sistema.';
$string['login'] = 'Entrar';
$string['loginas'] = 'Entrar como';
$string['loginguest'] = 'Entrar como invitado';
$string['loginsite'] = 'Entrar al sitio';
$string['loginsteps'] = 'Para tener acceso completo a los cursos necesita crear una cuenta para usted en este sitio web. Adems, cada uno de los cursos puede tener una clave de acceso que necesitar para entrar en los mismos. Estos son los pasos a seguir:
   <OL size=2>
   <LI>Rellene la <A HREF=$a>Solicitud de alta</A>.
   <LI>El sistema le enviar un correo electrnico para verificar que su direccin es correcta.
   <LI>Lea el correo y confirme su alta.
   <LI>Para entrar en los cursos se le pedir una \"clave de acceso\", que se le enviar cuando se matricule en los mismos.
   <LI>A partir de ese momento no necesitar utilizar ms que su nombre y contrasea.
   </OL>';
$string['loginstepsnone'] = 'Hola.<P>Para poder tener acceso completo a los cursos necesita crear
una cuenta.<P>Todo lo que tiene que hacer es inscribirse en esta pgina.
<P>';
$string['loginto'] = 'Entrar a $a';
$string['loginusing'] = 'Entre aqu usando su nombre y contrasea';
$string['logout'] = 'Salir';
$string['logs'] = 'Registros';
$string['mainmenu'] = 'Men principal';
$string['makeafolder'] = 'Crear una carpeta';
$string['makeeditable'] = 'Si hace \'$a\' editable por el servidor web (p.e. apache) podr editar este archivo directamente desde esta pgina.';
$string['managedatabase'] = 'Administrar la base de datos';
$string['managefilters'] = 'Filtros';
$string['managemodules'] = 'Administracin de mdulos';
$string['markedthistopic'] = 'Este tema est resaltado como tema actual';
$string['markthistopic'] = 'Marcar este tema como el tema actual';
$string['maximumchars'] = 'Mximo de $a caracteres';
$string['maximumgrade'] = 'Calificacin mxima';
$string['maximumshort'] = 'Mx.';
$string['maxsize'] = 'Tamao mximo: $a';
$string['min'] = 'minuto';
$string['mins'] = 'minutos';
$string['miscellaneous'] = 'Miscelnea';
$string['missingcategory'] = 'Necesita elegir una categora';
$string['missingcity'] = 'Falta la ciudad';
$string['missingcountry'] = 'Falta el pas';
$string['missingdescription'] = 'Falta la descripcin';
$string['missingemail'] = 'Falta la direccin de correo electrnico';
$string['missingfirstname'] = 'Falta el nombre';
$string['missingfullname'] = 'Falta el nombre completo';
$string['missinglastname'] = 'Falta el apellido';
$string['missingname'] = 'Falta el nombre';
$string['missingnewpassword'] = 'Falta la nueva contrasea';
$string['missingpassword'] = 'Falta la contrasea';
$string['missingshortname'] = 'Falta el nombre corto';
$string['missingshortsitename'] = 'Falta el nombre corto del sitio';
$string['missingsitedescription'] = 'Falta la descripcin del sitio';
$string['missingsitename'] = 'Falta el nombre del sitio';
$string['missingstrings'] = 'Revise las cadenas (strings) perdidas';
$string['missingstudent'] = 'Debe elegir algo';
$string['missingsummary'] = 'No hay informe';
$string['missingteacher'] = 'Debe elegir algo';
$string['missingurl'] = 'Falta la URL';
$string['missingusername'] = 'Colocar: nombre de usuario';
$string['modified'] = 'Modificado';
$string['moduledeleteconfirm'] = 'Est a punto de borrar completamente el mdulo \'$a\'.  Esto eliminar completamente todo lo que haya en la base de datos asociado con este mdulo. Est SEGURO de que quiere continuar?';
$string['moduledeletefiles'] = 'Todos los datos asociados con el mdulo \'$a->module\' han sido eliminados de la base de datos. Para completar la eliminacin (y prevenir que el mdulo se reinstale por s mismo) debera borrar ahora el siguiente directorio de su servidor: $a->directory';
$string['modulesetup'] = 'Instalando el mdulo de tablas';
$string['modulesuccess'] = 'El mdulo de tablas $a se instal correctamente';
$string['moodleversion'] = 'Versin de Moodle';
$string['mostrecently'] = 'ms recientemente';
$string['move'] = 'Mover';
$string['movecategoryto'] = 'Mover categora a:';
$string['movecourseto'] = 'Mover curso a:';
$string['movedown'] = 'Mover hacia abajo';
$string['movefilestohere'] = 'Mover archivos aqu';
$string['movefull'] = 'Mover $a a este lugar';
$string['movehere'] = 'Mover aqu';
$string['moveselectedcoursesto'] = 'Mover los cursos seleccionados a...';
$string['movetoanotherfolder'] = 'Mover a otra carpeta';
$string['moveup'] = 'Mover hacia arriba';
$string['mustconfirm'] = 'Necesita confirmar el acceso';
$string['mycourses'] = 'Mis cursos';
$string['name'] = 'Nombre';
$string['namesocial'] = 'seccin';
$string['nametopics'] = 'tema';
$string['nameweeks'] = 'semana';
$string['needed'] = 'Requerido';
$string['never'] = 'Nunca';
$string['neverdeletelogs'] = 'No borrar nunca los registros';
$string['new'] = 'Nuevo';
$string['newaccount'] = 'Nueva cuenta';
$string['newcourse'] = 'Nuevo curso';
$string['newpassword'] = 'Nueva contrasea';
$string['newpasswordtext'] = 'Hola $a->firstname,

La contrasea de su cuenta en \'$a->sitename\' se ha modificado, dndosele una nueva contrasea temporal.

   Nombre de usuario: $a->username

   contrasea: $a->newpassword

Dirjase a esta pgina y cambie esta contrasea temporal por una que pueda recordar mejor:

   $a->link

Atte. \'$a->sitename\' El Administrador,

$a->signoff';
$string['newpicture'] = 'Imagen nueva';
$string['newsitem'] = 'nuevo tem';
$string['newsitems'] = 'nuevos tems';
$string['newsitemsnumber'] = 'Nuevos tems para ver';
$string['newuser'] = 'Nuevo usuario';
$string['newusers'] = 'Nuevos usuarios';
$string['next'] = 'Siguiente';
$string['no'] = 'No';
$string['nocoursesfound'] = 'No se encontraron cursos que contengan las palabras \'$a\'';
$string['nocoursesyet'] = 'No hay cursos en esta categora';
$string['noexistingadmins'] = 'No existen administradores. Este es un error serio por lo que nunca debera ver este mensage.';
$string['noexistingcreators'] = 'No existen autores';
$string['noexistingstudents'] = 'No hay alumnos';
$string['noexistingteachers'] = 'No hay profesores';
$string['nofilesselected'] = 'No se han seleccionado archivos para restaurar';
$string['nofilesyet'] = 'An no se han colocado archivos en su curso';
$string['nograde'] = 'No hay calificacin';
$string['noimagesyet'] = 'An no se han colocado imgenes en su curso';
$string['nomorecourses'] = 'No se encontraron ms cursos coincidentes';
$string['none'] = 'Ninguno';
$string['nopotentialadmins'] = 'No hay administradores posibles';
$string['nopotentialcreators'] = 'No hay autores posibles';
$string['nopotentialstudents'] = 'No hay alumnos posibles';
$string['nopotentialteachers'] = 'No hay profesores posibles';
$string['normal'] = 'Normal';
$string['normalfilter'] = 'Filtro normal';
$string['nostudentsyet'] = 'An no se ha inscrito ningn alumno en este curso';
$string['nosuchemail'] = 'No existe esa direccin de correo';
$string['notavailable'] = 'No disponible';
$string['noteachersyet'] = 'An no hay profesores en ese curso';
$string['notenrolled'] = '$a no est inscrito en este curso.';
$string['noteuserschangednonetocourse'] = 'Nota: los usuarios del curso deben ser restaurados cuando se restauran los datos de usuario. Esta configuracin ha sido cambiada para usted.';
$string['nothingnew'] = 'Sin novedades desde la ltima entrada';
$string['notincluded'] = 'No incluido';
$string['nousersmatching'] = 'No se ha encontrado ningn usuario registrado como $a\' ';
$string['nousersyet'] = 'An no hay usuarios';
$string['now'] = 'ahora';
$string['numberweeks'] = 'Nmero de semanas /  temas';
$string['numdays'] = '$a das';
$string['numhours'] = '$a horas';
$string['numminutes'] = '$a minutos';
$string['numviews'] = '$a vistas';
$string['numweeks'] = '$a semanas';
$string['numwords'] = '$a palabras';
$string['numyears'] = '$a aos';
$string['ok'] = 'OK';
$string['opentoguests'] = 'Acceso de invitados';
$string['optional'] = 'opcional';
$string['order'] = 'Ordenar';
$string['other'] = 'Otro';
$string['outline'] = 'Diagrama';
$string['page'] = 'Pgina';
$string['parentlanguage'] = 'es';
$string['participants'] = 'Participantes';
$string['password'] = 'Contrasea';
$string['passwordchanged'] = 'La contrasea ha cambiado';
$string['passwordconfirmchange'] = 'Confirmar el cambio de contrasea';
$string['passwordrecovery'] = 'S, aydeme a entrar';
$string['passwordsdiffer'] = 'Las contraseas no coinciden';
$string['passwordsent'] = 'Se ha enviado la contrasea';
$string['passwordsenttext'] = '   <P>El sistema ha enviado un correo electrnico a $a->email.
   <P><B>Revise su correo para recibir una nueva contrasea</B>
   <P>La nueva contrasea se genera automticamente, por lo que tal vez Ud. desee
   <A HREF=$a->link>cambiarla</A> por una que le sea ms fcil de recordar.';
$string['people'] = 'Personas';
$string['personalprofile'] = 'Informacin personal';
$string['phone'] = 'Telfono';
$string['phpinfo'] = 'PHP info';
$string['popupwindow'] = 'Abrir el archivo en una nueva ventana';
$string['potentialadmins'] = 'Administradores posibles';
$string['potentialcreators'] = 'Autores de curso posibles';
$string['potentialstudents'] = 'Alumnos posibles';
$string['potentialteachers'] = 'Profesores posibles';
$string['preferredlanguage'] = 'Idioma preferido';
$string['preview'] = 'Vista previa';
$string['previeworchoose'] = 'Vista previa o elegir un entorno';
$string['publicdirectory'] = 'Directorio pblico';
$string['publicdirectory0'] = 'Por favor no publique este sitio';
$string['publicdirectory1'] = 'Publicar slo el nombre del sitio';
$string['publicdirectory2'] = 'Publicar el nombre del sitio con un enlace';
$string['publicsitefileswarning'] = 'Nota: los archivos colocados aqu estn accesibles a todos';
$string['question'] = 'Pregunta';
$string['readme'] = 'LEAME';
$string['recentactivity'] = 'Actividad reciente';
$string['recentactivityreport'] = 'Informe completo de la actividad reciente';
$string['registration'] = 'Registrar Moodle';
$string['registrationemail'] = 'Notificaciones por email';
$string['registrationinfo'] = '<p>Esta pgina le facilita el registro de su sitio Moodle en moodle.org. El registro es gratuito. El beneficio principal de registrarse es que se le incorporar a una lista de correo de poco volumen pero a la que se envan notificaciones importantes tales como alertas de seguridad y el lanzamiento de nuevas versiones de Moodle.</p>
<p>Por defecto, su informacin se mantendr en privado y nunca ser vendida o traspasada a nadie. La nica razn para recabar esta informacin es la de servir de soporte y ayudar a crear una imagen estadstica de la comunidad Moodle en su totalidad.</p>
<p>Usted puede elegir permitir que el nombre de su sitio, pas y URL se aadan a la lista pblica de Sitios Moodle.</p>
<p>Todos los nuevos registros se verifican manualmente antes de ser aadidos a la lista, pero una vez que el suyo haya sido aadido usted puede actualizar su registro (y la informacin en la lista pblica) en cualquier momento reenviando este formulario.<p>';
$string['registrationno'] = 'No, no deseo recibir mensajes por email';
$string['registrationsend'] = 'Enviar informacin de registro a Moodle.org';
$string['registrationyes'] = 'Si, notifqueme por favor cuestiones importantes';
$string['removeadmin'] = 'Quitar administrador';
$string['removecreator'] = 'Quitar autor de curso';
$string['removestudent'] = 'Quitar alumno';
$string['removeteacher'] = 'Quitar profesor';
$string['rename'] = 'Renombrar';
$string['renamefileto'] = 'Renombrar <b>$a</b> a';
$string['required'] = 'Requerido';
$string['requireskey'] = 'Este curso requiere una clave de acceso';
$string['resortcoursesbyname'] = 'Reordenar cursos por nombre';
$string['resources'] = 'Recursos';
$string['restore'] = 'Restaurar';
$string['restorecancelled'] = 'Restauracin cancelada';
$string['restorecoursenow'] = 'Restaurar este curso ahora!';
$string['restorefinished'] = 'Restauracin completada con xito';
$string['restoreto'] = 'Restaurar a';
$string['returningtosite'] = 'Alumnos inscritos';
$string['revert'] = 'Deshacer';
$string['role'] = 'Nivel';
$string['savechanges'] = 'Guardar cambios';
$string['scale'] = 'Nivel';
$string['scales'] = 'Niveles';
$string['scalescustom'] = 'Niveles personalizados';
$string['scalescustomcreate'] = 'Aadir un nuevo nivel';
$string['scalescustomno'] = 'An no se ha creado ningn nivel personalizado';
$string['scalesstandard'] = 'Niveles estndar';
$string['scheduledbackupstatus'] = 'Estado de la programacin de las Copias de Seguridad';
$string['search'] = 'Buscar';
$string['searchagain'] = 'Volver a buscar';
$string['searchcourses'] = 'Buscar cursos';
$string['searchhelp'] = 'Puede buscar muchas palabras al mismo tiempo.<p> Si coloca una o ms palabras, el buscador encuentra todos los mensajes que contengan esa o esas palabras en cualquier lugar.<br /> Si coloca varias palabras separadas por el signo de adicin (+) aparecern los resultados que contengan todas esas palabras en el orden exacto en el que fueron colocadas.<br /> Si coloca un signo de sustraccin (-) antes de una palabra se mostrarn todos los mensajes que contengan la o las otras plabras pero que no contengan la palabra antecedida por este signo.';
$string['searchresults'] = 'Resultados de la bsqueda';
$string['sec'] = 'segundo';
$string['secs'] = 'segundos';
$string['section'] = 'Seccin';
$string['sections'] = 'Secciones';
$string['select'] = 'Seleccionar';
$string['selectacountry'] = 'Seleccione su pas';
$string['selectednowmove'] = '$a archivos seleccionados para moverlos. Ahora vaya al sitio de destino y presione \'Mover archivos aqu\'';
$string['senddetails'] = 'Recordar por correo electrnico';
$string['separateandconnected'] = 'Vas de conocimiento separadas y conectadas';
$string['serverlocaltime'] = 'Hora local del servidor';
$string['settings'] = 'Configuracin';
$string['shortname'] = 'Nombre corto';
$string['shortnametaken'] = 'Esta abreviatura ya se usa para otro curso ($a)';
$string['shortsitename'] = 'Nombre corto para el sitio (una palabra)';
$string['show'] = 'Mostrar';
$string['showall'] = 'Mostrar todos los $a';
$string['showallcourses'] = 'Mostrar todos los cursos';
$string['showalltopics'] = 'Mostrar todos los temas';
$string['showallusers'] = 'Mostrar todos los usuarios';
$string['showallweeks'] = 'Mostrar todas las semanas';
$string['showgrades'] = 'Mostrar calificaciones';
$string['showlistofcourses'] = 'Mostrar lista de cursos';
$string['showonlytopic'] = 'Mostrar slo el tema $a';
$string['showonlyweek'] = 'Mostrar slo semana $a';
$string['showrecent'] = 'Mostrar la actividad reciente';
$string['showtheselogs'] = 'Mostrar registros';
$string['site'] = 'Sitio';
$string['sitefiles'] = 'Archivos del sitio';
$string['sitelogs'] = 'Registros';
$string['sitenews'] = 'Novedades';
$string['sites'] = 'Sitios';
$string['sitesettings'] = 'Configuracin de la pgina de inicio';
$string['size'] = 'Tamao';
$string['socialheadline'] = 'Foro de debate, ltimos temas';
$string['someallowguest'] = 'Algunos cursos pueden permitir el acceso como invitado';
$string['someerrorswerefound'] = 'Alguna informacin se ha perdido o es incorrecta. Mire abajo para conocer los detalles.';
$string['sortby'] = 'Ordenar por';
$string['startdate'] = 'Fecha de inicio del curso';
$string['startsignup'] = 'Solicitud de alta';
$string['state'] = 'Estado/Provincia';
$string['status'] = 'Estado';
$string['strftimedate'] = '%%d de %%B de %%Y';
$string['strftimedateshort'] = ' %%d de %%B ';
$string['strftimedatetime'] = ' %%d de %%B de %%Y, %%H:%%M';
$string['strftimedaydate'] = ' %%A, %%d de %%B de %%Y ';
$string['strftimedaydatetime'] = ' %%A, %%d de %%B de %%Y, %%H:%%M';
$string['strftimerecent'] = ' %%d de %%b, %%H:%%M ';
$string['strftimerecentfull'] = ' %%a, %%d de %%b de %%Y, %%H:%%M';
$string['strftimetime'] = ' %%H:%%M';
$string['stringsnotset'] = 'Las siguientes cadenas no estn definidas en $a';
$string['studentnotallowed'] = 'Lo siento, pero no puede entrar en este curso como \'$a\'';
$string['students'] = 'Estudiantes';
$string['subcategories'] = 'Subcategoras';
$string['success'] = 'xito';
$string['summary'] = 'Informe';
$string['summaryof'] = 'Informe de $a';
$string['supplyinfo'] = 'Por favor, rellene los siguientes datos';
$string['teacheronly'] = 'para $a solamente';
$string['teacherroles'] = '$a roles';
$string['teachers'] = 'Profesores';
$string['textediting'] = 'Cuando edite texto';
$string['texteditor'] = 'Use formas estndar de HTML';
$string['textformat'] = 'Formato de texto';
$string['thanks'] = 'Gracias';
$string['theme'] = 'Entorno';
$string['themes'] = 'Entornos';
$string['themesaved'] = 'Se ha grabado el nuevo entorno';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Espa&#241;ol - Espa&#241;a';
$string['time'] = 'Hora';
$string['timezone'] = 'Zona horaria';
$string['to'] = 'A';
$string['today'] = 'Hoy';
$string['todaylogs'] = 'Registros de hoy';
$string['toomanytoshow'] = 'Hay demasiados usuarios para mostrarlos aqu';
$string['topic'] = 'Tema';
$string['topichide'] = 'Ocultar este tema de $a';
$string['topicoutline'] = 'Diagrama de temas';
$string['topicshow'] = 'Mostrar este tema a $a';
$string['total'] = 'Total';
$string['turneditingoff'] = 'Desactivar edicin';
$string['turneditingon'] = 'Activar edicin';
$string['undecided'] = 'No decidido';
$string['unenrol'] = 'Desmatricular';
$string['unenrolme'] = 'Quitar de $a';
$string['unenrolsure'] = 'Est seguro de que desea borrar a $a de este curso?';
$string['unknowncategory'] = 'Categora desconocida';
$string['unpacking'] = 'Desempaquetando $a';
$string['unsafepassword'] = 'Contrasea insegura - intente alguna otra';
$string['unusedaccounts'] = 'Las cuentas no usadas durante ms de $a das son automticamente dadas de baja.';
$string['unzip'] = 'Descomprimir';
$string['unzippingbackup'] = 'Descomprimiendo copia de seguridad';
$string['up'] = 'Arriba';
$string['update'] = 'Actualizar';
$string['updated'] = 'Actualizado: $a';
$string['updatemyprofile'] = 'Actualizar informacin personal';
$string['updatesevery'] = 'Actualizado cada $a segundos';
$string['updatethis'] = 'Actualizar $a';
$string['updatethiscourse'] = 'Actualizar este curso';
$string['updatinga'] = 'Actualizando $a';
$string['updatingain'] = 'Actualizando $a->what en $a->in';
$string['upload'] = 'Subir';
$string['uploadafile'] = 'Subir un archivo';
$string['uploadedfileto'] = 'Se ha subido $a->file a $a->directory';
$string['uploadnofilefound'] = 'No se ha encontrado ningn archivo, est seguro de haber seleccionado uno para subir?';
$string['uploadproblem'] = 'Ha ocurrido un problema desconocido mientras se suba el archivo \'$a\' (quiz era demasiado grande)';
$string['uploadthisfile'] = 'Subir este archivo';
$string['user'] = 'Usuario';
$string['userdeleted'] = 'Esta cuenta se ha cancelado';
$string['userdescription'] = 'Descripcin';
$string['userfiles'] = 'Archivos de usuario';
$string['username'] = 'Nombre de usuario';
$string['usernameexists'] = 'Este nombre de usuario ya existe, por favor elija otro';
$string['userprofilefor'] = 'Informacin personal de $a';
$string['users'] = 'Usuarios';
$string['usersnew'] = 'Nuevos usuarios';
$string['userzones'] = 'Zonas de usuario';
$string['usingexistingcourse'] = 'Usar curso existente';
$string['view'] = 'Vista';
$string['webpage'] = 'Pgina web';
$string['week'] = 'Semana';
$string['weekhide'] = 'Ocultar esta semana de $a';
$string['weeklyoutline'] = 'Diagrama semanal';
$string['weekshow'] = 'Mostrar esta semana a $a';
$string['welcometocourse'] = 'Bienvenido a $a';
$string['welcometocoursetext'] = 'Bienvenido al curso de $a->coursename.

Una de las primeras cosas que debera hacer es editar su pgina de informacin personal dentro del curso, de forma que podamos saber ms cosas sobre usted:

  $a->profileurl';
$string['whattocallzip'] = 'Como quiere llamar al archivo zip?';
$string['withchosenfiles'] = 'Con los archivos escogidos';
$string['withoutuserdata'] = 'sin datos de usuario';
$string['withuserdata'] = 'con datos de usuario';
$string['wordforstudent'] = 'Su palabra para estudiante';
$string['wordforstudenteg'] = 'por ejemplo: estudiante, alumno, ejecutivo, etc.';
$string['wordforstudents'] = 'Su palabra para estudiantes';
$string['wordforstudentseg'] = 'por ejemplo: Estudiantes, Participantes, etc.';
$string['wordforteacher'] = 'Su palabra para profesor';
$string['wordforteachereg'] = 'por ejemplo: Maestro, Profesor, Tutor, etc.';
$string['wordforteachers'] = 'Su palabra para Profesores';
$string['wordforteacherseg'] = 'por ejemplo: Maestros, Profesores, Tutores, etc.';
$string['writingcategoriesandquestions'] = 'Escribiendo categoras y preguntas';
$string['writingcoursedata'] = 'Escribiendo datos del curso';
$string['writingeventsinfo'] = 'Escribiendo informacin de eventos';
$string['writinggeneralinfo'] = 'Escribiendo informacin general';
$string['writinggroupsinfo'] = 'Escribiendo informacin de grupos';
$string['writingheader'] = 'Escribiendo encabezado';
$string['writingloginfo'] = 'Escribiendo informacin de registros';
$string['writingmoduleinfo'] = 'Escribiendo informacin de los mdulos';
$string['writingscalesinfo'] = 'Escribiendo informacin de niveles';
$string['writinguserinfo'] = 'Escribiendo informacin de usuarios';
$string['wrongpassword'] = 'Contrasea incorrecta para este usuario';
$string['yes'] = 'S';
$string['youareabouttocreatezip'] = 'Est a punto de crear un archivo zip conteniendo';
$string['youaregoingtorestorefrom'] = 'Va a restaurar de:';
$string['yourlastlogin'] = 'Su ltima entrada fue el';
$string['yourself'] = 'usted';
$string['yourteacher'] = 'su $a';
$string['zippingbackup'] = 'Comprimiendo copia de seguridad';

?>
